about summary refs log tree commit diff
path: root/iconv
diff options
context:
space:
mode:
Diffstat (limited to 'iconv')
-rw-r--r--iconv/gconv_trans.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/iconv/gconv_trans.c b/iconv/gconv_trans.c
index ea02c95e84..a6e468e248 100644
--- a/iconv/gconv_trans.c
+++ b/iconv/gconv_trans.c
@@ -79,8 +79,8 @@ __gconv_transliterate (struct __gconv_step *step,
     return (winbuf == winbufend
 	    ? __GCONV_EMPTY_INPUT : __GCONV_INCOMPLETE_INPUT);
 
-  /* The array starting at FROM_IDX contains indeces to the string table
-     in FROM_TBL.  The indeces are sorted wrt to the strings.  I.e., we
+  /* The array starting at FROM_IDX contains indices to the string table
+     in FROM_TBL.  The indices are sorted wrt to the strings.  I.e., we
      are doing binary search.  */
   low = 0;
   high = size;